@@ -8,7 +8,7 @@
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Document::Mapping;
-$ElasticSearchX::Model::Document::Mapping::VERSION = '0.2.0';
+$ElasticSearchX::Model::Document::Mapping::VERSION = '0.2.1';
 use strict;
 use warnings;
 use Moose::Util::TypeConstraints;
@@ -31,7 +31,8 @@ sub maptc {
 $MAPPING{Any} = sub {
 
     my ( $attr, $tc ) = @_;
-    return (
+
+    my %mapping = (
         store => $attr->store,
         $attr->index            ? ( index          => $attr->index )   : (),
         $attr->type eq 'object' ? ( dynamic        => $attr->dynamic ) : (),
@@ -40,6 +41,7 @@ $MAPPING{Any} = sub {
         type => 'string',
         $attr->analyzer->[0] ? ( analyzer => $attr->analyzer->[0] ) : (),
     );
+    return _set_doc_values(%mapping);
 };
 
 $MAPPING{Str} = sub {
@@ -50,15 +52,17 @@ $MAPPING{Str} = sub {
     {
         my @analyzer = @{ $attr->{analyzer} };
         push( @analyzer, 'standard' ) unless (@analyzer);
-        return (
+        return _set_doc_values(
             type   => 'multi_field',
             fields => {
                 (
                     $attr->not_analyzed
                     ? (
                         $attr->name => {
-                            store => $attr->store,
-                            index => 'not_analyzed',
+                            store        => $attr->store,
+                            index        => 'not_analyzed',
+                            ignore_above => 2048,
+                            doc_values   => \1,
                             !$attr->include_in_all
                             ? ( include_in_all => \0 )
                             : (),
@@ -72,7 +76,8 @@ $MAPPING{Str} = sub {
                     store => $attr->store,
                     index => 'analyzed',
                     $attr->boost ? ( boost => $attr->boost ) : (),
-                    type => $attr->type,
+                    type      => $attr->type,
+                    fielddata => { format => 'disabled' },
                     %term,
                     analyzer => shift @analyzer
                 },
@@ -82,7 +87,8 @@ $MAPPING{Str} = sub {
                             store => $attr->store,
                             index => 'analyzed',
                             $attr->boost ? ( boost => $attr->boost ) : (),
-                            type => $attr->type,
+                            type      => $attr->type,
+                            fielddata => { format => 'disabled' },
                             %term,
                             analyzer => $_
                             }
@@ -91,22 +97,26 @@ $MAPPING{Str} = sub {
             }
         );
     }
-    return ( index => 'not_analyzed', %term, maptc( $attr, $tc->parent ) );
+    return _set_doc_values(
+        index        => 'not_analyzed',
+        ignore_above => 2048,
+        %term, maptc( $attr, $tc->parent )
+    );
 };
 
 $MAPPING{Num} = sub {
     my ( $attr, $tc ) = @_;
-    return ( maptc( $attr, $tc->parent ), type => 'float' );
+    return _set_doc_values( maptc( $attr, $tc->parent ), type => 'float' );
 };
 
 $MAPPING{Int} = sub {
     my ( $attr, $tc ) = @_;
-    return ( maptc( $attr, $tc->parent ), type => 'integer' );
+    return _set_doc_values( maptc( $attr, $tc->parent ), type => 'integer' );
 };
 
 $MAPPING{Bool} = sub {
     my ( $attr, $tc ) = @_;
-    return ( maptc( $attr, $tc->parent ), type => 'boolean' );
+    return _set_doc_values( maptc( $attr, $tc->parent ), type => 'boolean' );
 };
 
 $MAPPING{ScalarRef} = sub {
@@ -153,7 +163,7 @@ $MAPPING{'MooseX::Types::ElasticSearch::Location'} = sub {
     my ( $attr, $tc ) = @_;
     my %mapping = maptc( $attr, $tc->parent );
     delete $mapping{$_} for (qw(index store));
-    return ( %mapping, type => 'geo_point' );
+    return ( %mapping, type => 'geo_point', doc_values => \1 );
 };
 
 $MAPPING{'ElasticSearchX::Model::Document::Types::Type[]'} = sub {
@@ -169,9 +179,30 @@ $MAPPING{'ElasticSearchX::Model::Document::Types::Type[]'} = sub {
 
 $MAPPING{'DateTime'} = sub {
     my ( $attr, $tc ) = @_;
-    return ( maptc( $attr, $tc->parent ), type => 'date' );
+    return _set_doc_values(
+        maptc( $attr, $tc->parent ),
+        type       => 'date',
+        doc_values => \1
+    );
 };
 
+sub _set_doc_values {
+    my %mapping = @_;
+
+    if ( $mapping{type} eq 'string'
+        && ( $mapping{index} || 'analyzed' ) eq 'analyzed' )
+    {
+        $mapping{fielddata} = { format => 'disabled' };
+        delete $mapping{doc_values};
+    }
+    else {
+        $mapping{doc_values} = \1;
+        delete $mapping{fielddata};
+    }
+    return %mapping
+
+}
+
 __END__
 
 =pod
@@ -184,7 +215,7 @@ ElasticSearchX::Model::Document::Mapping
 
 =head1 VERSION
 
-version 0.2.0
+version 0.2.1
 
 =head1 AUTHOR
 
